@@ -1,13 +1,17 @@
 
-__version__ = '0.0.5'
+__version__ = '0.0.9'
 
+from .conf import *
+from .enforcer import *
 from .ferry import *
 from .meta import *
 from .nodes import *
 from .terrors import *
 from .validation import *
 
-__all__ = [*ferry.__all__,
+__all__ = [*conf.__all__,
+           *enforcer.__all__,
+           *ferry.__all__,
            *meta.__all__,
            *nodes.__all__,
            *terrors.__all__,
